==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetBatchSchedules.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetBatchSchedules] (
	@VCC VARCHAR(50) = NULL, 
	@SearchCriteria VARCHAR(50) = NULL,
	@SearchExpression VARCHAR(500) = NULL,
	@ExtendedContent BIT = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	DECLARE @SQL NVARCHAR(MAX)
	SET @SQL = '
		SET NOCOUNT ON
			
		SELECT BS.[VCC]									''vcc'',
				BS.[Id]									''id'',
				BS.[BatchType]							''batchType'',
				BS.[Frequency]							''frequency'',
				BS.[Weekday]							''weekday'',
				BS.[Monthday]							''monthday'',
				BS.[DaysInterval]						''daysInterval'',
				BS.[HoursInterval]						''hoursInterval'',
				BS.[StartDate]							''startDate'',
				BS.[EndDate]							''endDate'',
				BS.[FirstExecutionDate]					''firstExecutionDate'',
				BS.[LastExecutionDate]					''lastExecutionDate'',
				BS.[FinalExecutionDate]					''finalExecutionDate'', '

	IF @ExtendedContent = 1
		SET @SQL += '
				-- BS.[ExecutionList]						''executionList'',
				BS.[BatchData]							''batchData'', 
				BS.[ProcessFiltersId]					''processFiltersId'', '
				
	SET @SQL += '
				BS.[CreatedDate]						''createdDate'',
				BS.[CreatedByUserId]					''createdByUserId'',
				BS.[LastModifiedDate]					''lastModifiedDate'',
				BS.[LastModifiedByUserId]				''lastModifiedByUserId''
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			WHERE BS.[Id] IS NOT NULL '

	IF @VCC IS NOT NULL
		SET @SQL += '
				AND BS.[VCC] = ''' + @VCC + ''' '

	IF @SearchCriteria = 'NAME'
		SET @SQL += '
				AND BS.[Id] = ''' + @SearchExpression + ''' '

	IF @SearchCriteria = 'STATUS'
		SET @SQL += '
				AND BS.[Status] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','','')) '


	--select * FROM [dbo].[BatchSchedule] BS (NOLOCK)
	SET @SQL += '
			ORDER BY BS.[CreatedDate] DESC, BS.[Id]

		SET NOCOUNT OFF'

	-- EJECUTAMOS LA QUERY
	EXEC (@SQL)

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_7.1.0_database.tar.gz: database/mssql/procedures/GetBatchSchedules.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetBatchSchedules] (
	@VCC VARCHAR(50) = NULL, 
	@SearchCriteria VARCHAR(50) = NULL,
	@SearchExpression VARCHAR(500) = NULL,
	@ExtendedContent BIT = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	DECLARE @SQL NVARCHAR(MAX)
	SET @SQL = '
		SET NOCOUNT ON
			
		SELECT BS.[VCC]									''vcc'',
				BS.[Id]									''id'',
				BS.[BatchType]							''batchType'',
				BS.[Frequency]							''frequency'',
				BS.[Weekday]							''weekDay'',
				BS.[Monthday]							''monthDay'',
				BS.[DaysInterval]						''daysInterval'',
				BS.[HoursInterval]						''hoursInterval'',
				BS.[DaysToExpire]						''daysToExpire'',
				BS.[StartDate]							''startDate'',
				BS.[EndDate]							''endDate'',
				BS.[FirstExecutionDate]					''firstExecutionDate'',
				BS.[LastExecutionDate]					''lastExecutionDate'',
				BS.[FinalExecutionDate]					''finalExecutionDate'', '

	IF @ExtendedContent = 1
		SET @SQL += '
				-- BS.[ExecutionList]						''executionList'',
				BS.[BatchData]							''batchData'', 
				BS.[ProcessFiltersId]					''processFiltersId'', '
				
	SET @SQL += '
				BS.[CreatedDate]						''createdDate'',
				BS.[CreatedByUserId]					''createdByUserId'',
				BS.[LastModifiedDate]					''lastModifiedDate'',
				BS.[LastModifiedByUserId]				''lastModifiedByUserId''
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			WHERE BS.[Id] IS NOT NULL '

	IF @VCC IS NOT NULL
		SET @SQL += '
				AND BS.[VCC] = ''' + @VCC + ''' '

	IF @SearchCriteria = 'NAME'
		SET @SQL += '
				AND BS.[Id] = ''' + @SearchExpression + ''' '

	IF @SearchCriteria = 'STATUS'
		SET @SQL += '
				AND BS.[Status] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','','')) '


	--select * FROM [dbo].[BatchSchedule] BS (NOLOCK)
	SET @SQL += '
			ORDER BY BS.[CreatedDate] DESC, BS.[Id]

		SET NOCOUNT OFF'

	-- EJECUTAMOS LA QUERY
	EXEC (@SQL)

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
